@@ -1,3 +1,28 @@
+check_inputs_profiles <- function(levels) {
+  for (i in 1:length(levels)) {
+    check_vector <- !is.vector(levels[[i]])
+    check_name <- is.null(names(levels)[i])
+    if (check_vector | check_name) {
+      stop("Each item in ... must be a named vector where the names are attributes and the values in the vector are levels of that attribute.")
+    }
+  }
+}
+
+check_inputs_restrict <- function(profiles) {
+  # Check if profiles is a data frame
+  if (!is.data.frame(profiles)) {
+    stop("The 'profiles' argument must be a data frame.")
+  }
+
+  # Check if profiles has been created by the cbc_profiles function
+  if (!"profileID" %in% colnames(profiles)) {
+    stop(
+        "The 'profiles' data frame must be created using the 'cbc_profiles' function ",
+        "and contain the 'profileID' variable."
+    )
+  }
+}
+
 check_inputs_design <- function(
     profiles,
     n_resp,
